from django.shortcuts import redirect, get_list_or_404, render
from django.http import Http404
from models import Page

def page_detail(request, slug):

    parts = request.path_info.strip("/").split("/")

    pages = get_list_or_404(Page, slug=parts[-1])

    page = None

    if len(pages) > 1:
        print request.path_info
        for pg in pages:
            print pg.get_absolute_url()
            if pg.get_absolute_url() == request.path_info:
                page = pg

    if len(pages) == 1:
        page = pages[0]

    if not page:
        raise Http404

    if page.status == '0':
        if not request.user.is_authenticated():
            raise Http404

    if page.redirect_to:
        return redirect(page.redirect_to)

    template_file = 'fancy/pages/%s.html' % page.template

    return render(request, template_file, { 'page' : page })


from django.shortcuts import get_object_or_404, render
from django.template import RequestContext
from models import Album, AlbumItem

def album_index(request):
    albums = Album.objects.filter(status=1).order_by('-date_created')
    return render(request, 'fancy/gallery/album_index.html', {'albums':albums})

def album_detail(request,slug):
    album = get_object_or_404(Album, slug=slug)
    return render(request, 'fancy/gallery/album_detail.html', {'album':album})



from django.shortcuts import redirect, render, get_object_or_404
from django.core.paginator import Paginator, InvalidPage, EmptyPage
from datetime import date
from models import Post, Category
from taggit.models import Tag

def index(request):
	category_list = Category.objects.all()
	latest_posts = Post.objects.all()[:10]

	return render(request, 'fancy/blog/index.html', {
		'category_list': category_list,
		'latest_posts': latest_posts
	})

def detail(request,slug):
	post = get_object_or_404(Post,slug=slug)

	if post.redirect_to:
	    return redirect(post.redirect_to)

	return render(request, 'fancy/blog/detail.html', {'post':post})

def show_post_list(request,post_list,title="",archieve_type="category"):
	paginator = Paginator(post_list, 50)
	page = int(request.GET.get('page', '1'))

	try:
		page = int(request.GET.get('page', '1'))
	except ValueError:
		page = 1

	try:
		posts = paginator.page(page)
	except (EmptyPage, InvalidPage):
		posts = paginator.page(paginator.num_pages)

	return render(request, 'fancy/blog/posts.html', {
						'post_list' : posts,
						'title' : title,
						'archieve_type' : archieve_type
						})

def tag_index(request,slug):
	tag = get_object_or_404(Tag,slug=slug)
	post_list = Post.objects.filter(tags__slug__in=[slug.lower()],status=1)
	title = tag.name
	return show_post_list(request,post_list,title,'tag')

def category_index(request,slug):
	category = get_object_or_404(Category,slug=slug)
	post_list = Post.objects.filter(categories=category,status=1)
	title = category.name
	return show_post_list(request,post_list,title,'category')

def year_index(request,year):
	post_list=Post.objects.filter(date__year=year,status=1)
	title = date( int(year), 1, 1)
	return show_post_list(request,post_list,title,"year")

def month_index(request,year,month):
	post_list=Post.objects.filter(date__year=year, date__month=month,status=1)
	title = date( int(year), int(month), 1)
	return show_post_list(request,post_list,title,"month")








from django.conf.urls import patterns, url
from sitemap import PageSitemap
from django.contrib.sitemaps.views import sitemap
sitemaps = {
    'pages': PageSitemap,
}

urlpatterns = patterns('',
    url(r'^sitemap\.xml$', sitemap, {'sitemaps': sitemaps}),
    url(r'^(?P<slug>[-\w\/]+)/$',
        view='fancy.pages.views.page_detail',
        name='pages_page_detail'
    ),

)



from django.db import models
from django.utils.translation import ugettext_lazy as _
from mptt.models import MPTTModel
import settings
from fancy.gallery.models import Image, ModelWithImage
from datetime import datetime
from fancy.utils.models import MetadataModel, BaseModel
from django.contrib.contenttypes import generic
from django.core.urlresolvers import reverse

class Category(MPTTModel, BaseModel, ModelWithImage):
    name = models.CharField(_('Category name'), max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    description = models.TextField(_('Description'), blank=True)
    parent = models.ForeignKey("self", related_name="children", null=True, blank=True)

    class Meta(BaseModel.Meta):
        verbose_name = _('Product category')
        verbose_name_plural = _('Product categories')
        ordering = ('name',)

    def __unicode__(self):
        return self.name

    def get_absolute_url(self):
        if not getattr(self, '_slug', None):
            slugs = [ancestor.slug for ancestor in self.get_ancestors()]
            slugs.append(self.slug)

            url = '/'.join(slugs)

            self._slug = url
        return reverse('products_full_tree', kwargs={'slug' : str(self._slug) } )


class Product(MetadataModel, ModelWithImage, BaseModel):
    name = models.CharField(_('Product name'), max_length=200)
    slug = models.SlugField(_('Slug'), max_length=200, blank=True)
    price = models.DecimalField(_('Price'),max_digits=6,decimal_places=2,default=0)
    description = models.TextField(_('Description'))

    category = models.ForeignKey(Category, verbose_name=_('Product category'), related_name="products")

    STATUSES = (
        ('0', _('Out of stock')),
        ('1', _('In stock')),
    )
    status = models.CharField(_('Status'), max_length=1, choices=STATUSES, default='1')
    order_number = models.IntegerField(_('Order Number'),help_text=_('Ordering'),default=0)

    class Meta(BaseModel.Meta):
        verbose_name = _('Product')
        verbose_name_plural = _('Products')
        ordering = ('order_number','-id')

    def __unicode__(self):
        return self.name

    def save(self, *args, **kwargs):
        if self.slug == '':
            self.slug = slugify(self.name)

        super(Product, self).save(*args, **kwargs) # Call the "real" save() method.

    def can_order_multiple(self):
        return self.max_count > 1

    def get_price_as_cent(self):
        return int(self.price * 100)

    @models.permalink
    def get_absolute_url(self):
        if not getattr(self, '_slug', None):
            slugs = [ancestor.slug for ancestor in self.category.get_ancestors()]
            slugs.append(self.category.slug)
            slugs.append(self.slug)

            url = '/'.join(slugs)

            self._slug = url
        return ('products_full_tree', (), {'slug' : str(self._slug) } )



from django import forms
from mptt.forms import TreeNodeChoiceField
from models import Category

class CategoryForm(forms.ModelForm):

    parent = TreeNodeChoiceField(queryset=Category.objects.all(), level_indicator=3*unichr(160), empty_label='---------', required=False)

    class Meta:
        model = Category
        fields = '__all__'
